@@ -39,4 +39,9 @@
 
 DEFINE_VECTOR_TYPE (string, char);
 
+/* Append a formatted string to the end of string 's'.  Returns the
+ * new length of 's'.  On error, returns -1.
+ */
+extern ssize_t string_append_format (string *s, const char *fs, ...);
+
 #endif /* NBDKIT_STRING_H */
