@@ -38,10 +38,16 @@ do_can (void)
 
   assert (can);
 
-  if (strcasecmp (can, "connect") == 0 ||
-      strcasecmp (can, "read") == 0)
+  if (strcasecmp (can, "connect") == 0)
     feature = 1;
 
+  else if (strcasecmp (can, "open") == 0 ||
+           strcasecmp (can, "read") == 0)
+    /* nbd_get_size won't work unless the server has sent export
+     * flags, which means we are able to open the export.
+     */
+    feature = nbd_get_size (nbd) >= 0;
+
   else if (strcasecmp (can, "tls") == 0)
     feature = nbd_get_tls_negotiated (nbd);
 
