@@ -27,13 +27,23 @@ requires $PYTHON --version
 # Python tests all fail on macOS because of SIP misfeature.
 requires_not test "$(uname)" = "Darwin"
 
-$NBDKIT -U - null --run '$PYTHON -c "
+define script <<'EOF'
 import nbd
 import sys
+
 h = nbd.NBD()
-addr = sys.argv[1]
+unixsocket = sys.argv[1]
+addr = ("AF_UNIX", unixsocket)
 h.aio_connect(addr)
 while h.aio_is_connecting():
     h.poll(1)
 assert h.aio_is_ready()
-" "$unixsocket"'
+
+# libnbd should be able to form a URI from this address.
+uri = h.get_uri()
+print("uri:", uri)
+assert uri == ("nbd+unix:///?socket=%s" % unixsocket)
+EOF
+export script
+
+$NBDKIT -U - null --run '$PYTHON -c "$script" "$unixsocket"'
